==> gen_boiler_plate-0.0.1.tar.gz: bin/gen_boiler_plate.dart <==
import 'package:process_run/shell_run.dart';
import 'package:interact/interact.dart';

void main(List<String> arguments) async {
  spittler();
  print("Creating Flutter Project");
  spittler();

  final boilerPlateType = ['Advanced', 'Basic'];
  final selection = Select(
    prompt: 'Choose BoilerPlate Type',
    options: boilerPlateType,
  ).interact();

  String selectedBoilerPlateType = boilerPlateType[selection];

  if (selectedBoilerPlateType == "Advanced") {
    print("Advanced Features include: Flavor, Firebase");
  }

  BoilerPlate boilerPlate = BoilerPlate(selectedBoilerPlateType);
  boilerPlate.create();
}

class BoilerPlate {
  String type;
  late String appName = "aqgromalin";
  late String packageName;
  late int androidLanguageSelection;
  late int iosLanguageSelection;

  BoilerPlate(this.type);

  List<String> androidLanguageOptions = ['Kotlin', 'Java'];
  List<String> iosLanguageOptions = ['Swift', 'ObjC'];

  String get androidLanguage =>
      androidLanguageOptions[androidLanguageSelection].toLowerCase();
  String get iosLanguage =>
      iosLanguageOptions[iosLanguageSelection].toLowerCase();

  create() async {
    // Get Input of App Name
    //
    appName = Input(
      prompt: 'Enter App Name',
      defaultValue: '', // optional, will provide the user as a hint
      initialText: '', // optional, will be autofilled in the input
      validator: (String x) {
        // optional
        if (x.isNotEmpty) {
          return true;
        } else {
          throw ValidationError(
              'App Name should not be empty. Please enter App Name');
        }
      },
    ).interact().toLowerCase();

    // Get Input of Package Name
    //
    packageName = Input(
      prompt: 'Enter Package Name',
      defaultValue: 'tech.vgts', // optional, will provide the user as a hint
      initialText: '', // optional, will be autofilled in the input
      validator: (String x) {
        // optional
        if (x.isNotEmpty) {
          return true;
        } else {
          throw ValidationError(
              'Package Name should not be empty. Please enter Package Name');
        }
      },
    ).interact().toLowerCase();

    // Prompt for Android Language selection
    androidLanguageSelection = Select(
      prompt: 'Android Language',
      options: androidLanguageOptions,
    ).interact();

    // Prompt for iOS Language selection
    iosLanguageSelection = Select(
      prompt: 'iOS Language',
      options: iosLanguageOptions,
    ).interact();

    spittler();

    await run("flutter --version");

    spittler();

    await run(
        "flutter create -t app --org $packageName -a $androidLanguage -i $iosLanguage $appName");

    spittler();

    setupBoilerPlate();
  }

  setupBoilerPlate() async {
    await run("sh bin/copy.sh $appName");
  }
}

spittler() {
  print(
      "---------------------------------------------------------------------------");
}

==> gen_boiler_plate-0.0.3.tar.gz: bin/gen_boiler_plate.dart <==
import 'package:process_run/shell_run.dart';
import 'package:interact/interact.dart';

void main(List<String> arguments) async {
  spittler();
  print("Creating Flutter Project");
  spittler();

  final boilerPlateType = ['Advanced', 'Basic'];
  final selection = Select(
    prompt: 'Choose BoilerPlate Type',
    options: boilerPlateType,
  ).interact();

  String selectedBoilerPlateType = boilerPlateType[selection];

  if (selectedBoilerPlateType == "Advanced") {
    print("Advanced Features include: Flavor, Firebase");
  }

  BoilerPlate boilerPlate = BoilerPlate(selectedBoilerPlateType);
  await boilerPlate.create();
  await boilerPlate.setupBoilerPlate();
}

class BoilerPlate {
  String type;
  late String appName = "boiler_plate";
  late String packageName;
  late int androidLanguageSelection;
  late int iosLanguageSelection;

  BoilerPlate(this.type);

  List<String> androidLanguageOptions = ['Kotlin', 'Java'];
  List<String> iosLanguageOptions = ['Swift', 'ObjC'];

  String get androidLanguage =>
      androidLanguageOptions[androidLanguageSelection].toLowerCase();
  String get iosLanguage =>
      iosLanguageOptions[iosLanguageSelection].toLowerCase();

  create() async {
    // Get Input of App Name
    //
    appName = Input(
      prompt: 'Enter App Name',
      defaultValue: '', // optional, will provide the user as a hint
      initialText: '', // optional, will be autofilled in the input
      validator: (String x) {
        // optional
        if (x.isNotEmpty) {
          return true;
        } else {
          throw ValidationError(
              'App Name should not be empty. Please enter App Name');
        }
      },
    ).interact().toLowerCase();

    // Get Input of Package Name
    //
    packageName = Input(
      prompt: 'Enter Package Name',
      defaultValue: 'tech.vgts', // optional, will provide the user as a hint
      initialText: '', // optional, will be autofilled in the input
      validator: (String x) {
        // optional
        if (x.isNotEmpty) {
          return true;
        } else {
          throw ValidationError(
              'Package Name should not be empty. Please enter Package Name');
        }
      },
    ).interact().toLowerCase();

    // Prompt for Android Language selection
    androidLanguageSelection = Select(
      prompt: 'Android Language',
      options: androidLanguageOptions,
    ).interact();

    // Prompt for iOS Language selection
    iosLanguageSelection = Select(
      prompt: 'iOS Language',
      options: iosLanguageOptions,
    ).interact();

    spittler();

    await run("flutter --version");

    spittler();

    await run(
        "flutter create -t app --org $packageName -a $androidLanguage -i $iosLanguage $appName");

    spittler();
  }

  setupBoilerPlate() async {
    await run("ls");
    await run("sh bin/copy.sh $appName");
    await run("sh bin/inject.sh $appName");
  }
}

spittler() {
  print(
      "---------------------------------------------------------------------------");
}
